pub struct RenderContext<'dsp, 'surf> { /* private fields */ }Expand description
The context used to draw to a Surface.
This is the whole point of this crate, and is the aperture used to actually draw with vector
graphics. It’s created from a Display and a Surface, and can be used to draw to the
surface.
See the RenderContext documentation for more information.
Implementations
Sourceimpl<'dsp, 'surf> RenderContext<'dsp, 'surf>
impl<'dsp, 'surf> RenderContext<'dsp, 'surf>
Sourcepub fn new(
display: &'dsp mut Display,
surface: &'surf mut Surface,
width: u32,
height: u32,
) -> Result<Self, Error>
pub fn new( display: &'dsp mut Display, surface: &'surf mut Surface, width: u32, height: u32, ) -> Result<Self, Error>
Create a new RenderContext from a Surface and a Display.
This creates a new RenderContext from a Surface and a Display. This is
the only way to create a RenderContext.
Sourcepub unsafe fn new_unchecked(
display: &'dsp mut Display,
surface: &'surf mut Surface,
width: u32,
height: u32,
) -> Result<Self, Error>
pub unsafe fn new_unchecked( display: &'dsp mut Display, surface: &'surf mut Surface, width: u32, height: u32, ) -> Result<Self, Error>
Create a new RenderContext without checking for exclusive access.
Safety
The same as new, but you need to make sure that there are no other OpenGL contexts
active on the current thread.